package cn.fw.valhalla.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : PublicPoolTypeEnum
 * @description : 公共池类型
 * @date: 2020-08-11 17:37
 */
public enum PublicPoolTypeEnum implements IEnum<Integer> {
    /**
     * 首保
     */
    FM(1, "首保"),
    /**
     * 例保
     */
    RM(2, "流失客户"),
    /**
     * 事故车
     */
    AD(3, "主动战败"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    PublicPoolTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static PublicPoolTypeEnum ofValue(final Integer value) {
        for (final PublicPoolTypeEnum typeEnum : PublicPoolTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final PublicPoolTypeEnum typeEnum : PublicPoolTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }
}
