package cn.fw.valhalla.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : StammkundeSourcesEnum
 * @description : 保有客池渠道来源
 * @date: 2020-08-11 17:37
 */
public enum StammkundeSourcesEnum implements IEnum<Integer> {
    /**
     * 新车
     */
    ORDER(10, "新车"),
    /**
     * 外集团
     */
    RECEPTION(20, "外集团"),
    /**
     * 二次分配
     */
    REDISTRIBUTION(30, "二次分配"),
    /**
     * 公共池
     */
    PUBLIC_POOL(40, "公共池"),
    /**
     * 系统分配
     */
    SYSTEMATIC(50, "系统分配"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    StammkundeSourcesEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static StammkundeSourcesEnum ofValue(final Integer value) {
        for (final StammkundeSourcesEnum typeEnum : StammkundeSourcesEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final StammkundeSourcesEnum typeEnum : StammkundeSourcesEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }
}
