package cn.fw.valhalla.domain.query;

import cn.fw.valhalla.common.utils.DateUtil;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;
import org.springframework.util.CollectionUtils;

import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author : kurisu
 * @className : CustomerCluePoolQueryVO
 * @description : 客户线索池查询
 * @date: 2020-11-20 15:49
 */
@Data
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class CustomerCluePoolQueryVO extends PoolQuery {
    private Integer type;
    /**
     * 任务开始时间 按月算
     */
    private String startTime;
    /**
     * 关单时间
     */
    private String closeTime;
    /**
     * 线索状态
     */
    private Integer status;
    /**
     * 成交人员id
     */
    private Long comUserId;
    /**
     * 成交人员名
     */
    private String comUserName;
    /**
     * 成交门店ids
     */
    private String comShops;
    /**
     * 贷款期客户
     */
    private Boolean loanCustomer;
    /**
     * 管理门店范围
     */
    private String scope;


    public Integer getLoanCustomer() {
        if (Objects.isNull(loanCustomer)) {
            return null;
        }
        return loanCustomer ? 1 : 0;
    }

    public Date getStartTime() {
        if (StringUtils.isNotBlank(startTime) && NumberUtils.isDigits(startTime)) {
            LocalDateTime localDateTime = Instant.ofEpochMilli(NumberUtils.toLong(startTime)).atZone(ZoneId.systemDefault()).toLocalDateTime();
            return DateUtil.localDateTime2Date(localDateTime);
        }
        return null;
    }

    public Date getCloseTime1() {
        if (StringUtils.isBlank(closeTime)) {
            return null;
        }
        String[] times = closeTime.split(",");
        if (StringUtils.isNotBlank(times[0]) && NumberUtils.isDigits(times[0])) {
            LocalDateTime localDateTime = Instant.ofEpochMilli(NumberUtils.toLong(times[0])).atZone(ZoneId.systemDefault()).toLocalDateTime();
            return DateUtil.getBeginInTime(DateUtil.localDateTime2Date(localDateTime));
        }
        return null;
    }

    public Date getCloseTime2() {
        if (StringUtils.isBlank(closeTime)) {
            return null;
        }
        String[] times = closeTime.split(",");
        if (times.length < TIME_STR_LENGTH) {
            return null;
        }
        if (StringUtils.isNotBlank(times[1]) && NumberUtils.isDigits(times[1])) {
            LocalDateTime localDateTime = Instant.ofEpochMilli(NumberUtils.toLong(times[1])).atZone(ZoneId.systemDefault()).toLocalDateTime();
            return DateUtil.getEndInTime(DateUtil.localDateTime2Date(localDateTime));
        }
        return null;
    }


    public List<Long> getScope() {
        if (StringUtils.isBlank(scope)) {
            return null;
        }
        return Arrays.stream(scope.split(","))
                .filter(s -> StringUtils.isNotBlank(s) && NumberUtils.isDigits(s))
                .map(Long::valueOf).distinct()
                .collect(Collectors.toList());
    }

    public List<Long> getComShops() {
        if (StringUtils.isBlank(comShops)) {
            return null;
        }
        List<Long> list = Arrays.stream(comShops.split(",")).filter(StringUtils::isNoneBlank).map(Long::valueOf).collect(Collectors.toList());
        if (CollectionUtils.isEmpty(list)) {
            return null;
        }
        return list;
    }
}
