package cn.fw.valhalla.domain.query;

import cn.fw.common.page.BasePageQuery;
import cn.fw.valhalla.common.utils.DateUtil;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.math.BigDecimal;
import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * 档案查询条件
 * @author kurisu
 */

@Data
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class CustomerQueryVO extends BasePageQuery {
    /**
     * 允许通过车主姓名、车架号、车牌号匹配
     */
    private String keyword;
    /**
     * 工作单位
     */
    private String companyName;
    /**
     * 区域code
     */
    private String regionCode;
    /**
     * 纬度
     */
    private BigDecimal lat;
    /**
     * 经度
     */
    private BigDecimal lng;
    /**
     * 客户登记
     */
    private List<String> levels = Collections.emptyList();
    /**
     * 标签
     */
    private List<String> tags = Collections.emptyList();
    /**
     * 建档时间(开始)
     */
    private Long leftCreatTime;
    /**
     * 建档时间(结束)
     */
    private Long rightCreatTime;
    /**
     * 品牌id
     */
    private Long brandId;
    /**
     * 车系id
     */
    private Long seriesId;
    /**
     * 车系id
     */
    private Long specId;
    /**
     * 车主出生月份
     */
    private Integer month;
    /**
     * 车主性别
     */
    private Integer gender;
    /**
     * 车主最小年龄
     */
    private Integer minAge;
    /**
     * 车主最大年龄
     */
    private Integer maxAge;
    /**
     * 客户类型;1:个人；2:单位
     */
    private Integer cusType;
    /**
     * 所属服务站id￿
     */
    private List<String> shopIds = Collections.emptyList();
    /**
     * 集团id
     */
    private Long groupId;
    /**
     * 专属顾问id
     */
    private Long consultantId;

    public Date getLeftCreatTime() {
        if (this.leftCreatTime != null) {
            return new Date(this.leftCreatTime);
        }
        return null;
    }

    public Date getRightCreatTime() {
        if (this.rightCreatTime != null) {
            return new Date(this.rightCreatTime);
        }
        return null;
    }

    public Date getStartBirthday() {
        if (minAge != null) {
            return DateUtil.getNowExpiredYear(minAge * -1);
        }
        return null;
    }

    public Date getEndBirthday() {
        if (maxAge != null) {
            return DateUtil.getNowExpiredYear(maxAge * -1);
        }
        return null;
    }
}