package cn.fw.valhalla.domain.vo.customer;

import cn.fw.valhalla.common.utils.DateUtil;
import cn.fw.valhalla.domain.db.customer.Customer;
import lombok.Data;
import lombok.ToString;

import java.math.BigDecimal;
import java.util.Date;
import java.util.Objects;
import java.util.Optional;

/**
 * @author : kurisu
 * @className : CarArchiveDTO
 * @description : 小程序首页档案信息
 * @date: 2020-08-26 17:57
 */
@Data
@ToString
public class CarArchiveVO {
    /**
     * 车辆id 即档案id
     */
    private Long carId;
    /**
     * 车牌号
     */
    private String plateNo;
    /**
     * 车型id
     */
    private Long seriesId;
    private Long brandId;
    /**
     * 车型id
     */
    private Long specId;
    /**
     * 车辆名称
     */
    private String carName;
    /**
     * 车架号
     */
    private String frameNo;
    /**
     * 车辆图片
     */
    private String image;
    /**
     * 是否是车主
     */
    private Boolean owner;
    /**
     * 车主名称
     */
    private String ownerName;
    /**
     * 档案id
     */
    private Long cusId;
    /**
     * 服务站id
     */
    private Long shopId;
    /**
     * 集团id
     */
    private Long groupId;
    /**
     * 座位数
     */
    private Integer seatCnt;
    /**
     * 购车价
     */
    private Long buyPrice;
    /**
     * 购买年限
     */
    private Integer buyYears;
    /**
     * 使用类型
     */
    private Integer useType;
    /**
     * 所属服务顾问
     */
    private Long adviserId;
    /**
     * 所属服务顾问
     */
    private String adviserName;
    /**
     * 是否是贷款客户
     */
    private boolean loanCustomer;
    /**
     * 分期期数
     */
    private Integer periods;
    /**
     * 贷款到期时间
     */
    private Date expires;
    /**
     * 商家信息
     */
    private DealerItem dealerInfoVO;

    public static CarArchiveVO with(Customer customer) {
        if (Objects.isNull(customer)) {
            return null;
        }
        CarArchiveVO vo = new CarArchiveVO();
        vo.setCarId(customer.getId());
        vo.setPlateNo(customer.getPlateNo());
        vo.setBrandId(customer.getBrandId());
        vo.setSeriesId(customer.getSeriesId());
        vo.setFrameNo(customer.getFrameNo());
        vo.setSpecId(customer.getSpecId());
        vo.setCarName(customer.getSeriesName().concat(" ").concat(Optional.ofNullable(customer.getSpecName()).orElse("")));
        vo.setCusId(customer.getId());
        vo.setShopId(customer.getShopId());
        vo.setGroupId(customer.getGroupId());
        vo.setAdviserId(customer.getAdviserId());
        //固定座位数为5
        vo.setSeatCnt(5);
        vo.setBuyPrice(Objects.isNull(customer.getBuyPrice()) ? 0 : customer.getBuyPrice() / 100);
        //默认1年
        vo.setBuyYears(Objects.isNull(customer.getBuyDate()) ? 1 : DateUtil.sub(new Date(), customer.getBuyDate(), "y") + 1);
        vo.setUseType(customer.getUseType().getValue());
        return vo;
    }

    public static DealerItem createDealerItem() {
        return new DealerItem();
    }

    @Data
    @ToString
    public static class DealerItem {
        /**
         * 商家id
         */
        private Long id;
        /**
         * 经销商名称
         */
        private String name;
        /**
         * 经销商logo
         */
        private String logo;

        /**
         * 主营品牌名称
         */
        private String brandName;

        /**
         * 联系电话
         */
        private String phone;
        /**
         * 地址
         */
        private String addr;

        /**
         * 经纬度
         */
        private BigDecimal lat;

        /**
         * 经纬度
         */
        private BigDecimal lng;
        /**
         * 距离
         */
        private Double distance;
        /**
         * 是否默认
         */
        private boolean defaulted;
    }
}
