package cn.fw.valhalla.rpc.crm;

import cn.fw.valhalla.rpc.crm.dto.CustomerDTO;
import cn.fw.crm.sdk.param.ToTenureDto;
import cn.fw.crm.sdk.result.CollectResultDto;
import cn.fw.crm.sdk.result.ShortCustomerDto;
import cn.fw.crm.sdk.service.CrmApiService;
import cn.fw.data.base.domain.common.Message;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Component;

import java.util.Objects;

/**
 * @author kurisu
 */
@Slf4j
@Component
public class CrmRpcService {
    private final CrmApiService crmApiService;


    public CrmRpcService(CrmApiService crmApiService) {
        this.crmApiService = crmApiService;

    }

    public CollectResultDto customerToCRM(ToTenureDto toTenureDto) {
        try {
            log.info("调用[crmApiService.receiveTenure]同步保有客信息,parm:{}", toTenureDto);
            Message<CollectResultDto> message = crmApiService.receiveTenure(toTenureDto);
            if (message.isSuccess()) {
                log.info("调用[crmApiService.receiveTenure]同步保有客信息成功,message: data:{}", message.getData());
                return message.getData();
            } else {
                log.warn("调用[crmApiService.receiveTenure]同步保有客信息失败,message: code:{}, result:{}", message.getCode(), message.getResult());
            }
        } catch (Exception ex) {
            log.error(ex.getMessage());
        }
        return null;
    }

    /**
     * 查询售前保有客信息
     *
     * @param cusId 保有客id
     * @return
     */
    public CustomerDTO getCustomer(Long cusId) {
        try {
            log.info("调用[crmApiService.selectCustomerInfo]查询保有客信息,memberId:{},dealerId:{}", cusId);
            Message<ShortCustomerDto> message = crmApiService.getCustomerById(cusId);
            if (message.isSuccess()) {
                log.info("调用[crmApiService.selectCustomerInfo]查询保有客信息成功,message: data:{}", message.getData());
                CustomerDTO customerDTO = new CustomerDTO();
                if (Objects.isNull(message.getData())) {
                    return null;
                }
                BeanUtils.copyProperties(message.getData(), customerDTO);
                return customerDTO;
            } else {
                log.warn("调用[crmApiService.selectCustomerInfo]查询保有客信息失败,message: code:{}, result:{}", message.getCode(), message.getResult());
            }
        } catch (Exception ex) {
            log.error(ex.getMessage());
        }
        return null;
    }

}
