package cn.fw.valhalla.controller.api;

import cn.fw.data.base.domain.common.Message;
import cn.fw.valhalla.sdk.api.ValhallaGeneralApiService;
import cn.fw.valhalla.sdk.param.ReachLogReq;
import cn.fw.valhalla.service.bus.ReachLogBizService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

import static cn.fw.common.web.util.ExceptionHandler.handleException;
import static cn.fw.common.web.util.ResultBuilder.failureWithMessage;
import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * @author : kurisu
 * @className : ValhallaGeneralApiServiceImpl
 * @description : 通用api实现
 * @date: 2020-11-11 16:01
 */
@Slf4j
@RestController
@RequestMapping("/api/valhalla/general")
public class ValhallaGeneralApiServiceImpl implements ValhallaGeneralApiService {

    private final ReachLogBizService reachLogBizService;

    @Autowired
    public ValhallaGeneralApiServiceImpl(final ReachLogBizService reachLogBizService) {
        this.reachLogBizService = reachLogBizService;
    }

    @PostMapping("/reach/save")
    @Override
    public Message<Void> saveReachLog(@Valid @RequestBody ReachLogReq reachLogReq) {
        final String msg = "保存进站记录[/reach/save]";
        log.info("{}: param[{}]", msg, reachLogReq);
        try {
            reachLogBizService.saveReachLog(reachLogReq);
            log.info("{} 操作成功", msg);
            return success();
        } catch (Exception ex) {
            handleException(ex, e -> log.error("{}失败：param[{}]", msg, reachLogReq, e));
            return failureWithMessage("保存进站记录失败");
        }
    }
}
