package cn.fw.valhalla.controller.app;

import cn.fw.common.page.AppPage;
import cn.fw.common.web.auth.LoginAuthBean;
import cn.fw.common.web.auth.annotation.CurrentUser;
import cn.fw.data.base.domain.common.Message;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.enums.AuthType;
import cn.fw.valhalla.domain.dto.LeaveAllocationDTO;
import cn.fw.valhalla.domain.enums.LeaveTodoTypeEnum;
import cn.fw.valhalla.domain.query.LeaveQueryVO;
import cn.fw.valhalla.domain.vo.LeaveNeedDoVO;
import cn.fw.valhalla.service.bus.LeaveNeedDoBizService;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import static cn.fw.common.web.util.ExceptionHandler.handleException;
import static cn.fw.common.web.util.ResultBuilder.failureWithMessage;
import static cn.fw.common.web.util.ResultBuilder.success;
import static cn.fw.valhalla.common.constant.MessageStr.QUERY_FAILURE;
import static cn.fw.valhalla.common.constant.MessageStr.SAVE_FAILURE;

/**
 * @author : kurisu
 * @className : LeaveNeedDoController
 * @description : 人员变动待处理事件
 * @date: 2020-08-15 14:52
 */
@Slf4j
@RestController
@Authorization(AuthType.APP)
@Validated
@RequestMapping("/app/leave2do")
public class LeaveNeedDoController {

    private final LeaveNeedDoBizService leaveNeedDoBizService;

    @Autowired
    public LeaveNeedDoController(final LeaveNeedDoBizService leaveNeedDoBizService) {
        this.leaveNeedDoBizService = leaveNeedDoBizService;
    }

    @GetMapping("/customer/list")
    public Message<AppPage<LeaveNeedDoVO>> save(@CurrentUser LoginAuthBean currentUser, final LeaveQueryVO queryVO) {
        final String msg = "保有客档案待分配人员列表[app/leave2do/customer/list]";
        try {
            queryVO.setType(LeaveTodoTypeEnum.CUSTOMER.getValue());
            log.info("{}: param[{}]", msg, queryVO);
            return success(leaveNeedDoBizService.getList(currentUser, queryVO),
                    data -> log.info("dataSize: {}", CollectionUtils.isEmpty(data.getData()) ? 0 : data.getData().size()));
        } catch (Exception ex) {
            handleException(ex, e -> log.error("{}失败: param[{}]", msg, queryVO, e));
            return failureWithMessage(QUERY_FAILURE);
        }
    }


    @PostMapping("/customer/allocation")
    public Message<Void> allocation(@CurrentUser LoginAuthBean currentUser, @RequestBody @Valid LeaveAllocationDTO dto) {
        final String msg = "保有客档案分配[app/leave2do/customer/allocation]";
        try {
            log.info("{}: param[{}]", msg, dto);
            leaveNeedDoBizService.allocation(currentUser, dto);
            return success();
        } catch (Exception ex) {
            handleException(ex, e -> log.error("{}失败: param[{}]", msg, dto, e));
            return failureWithMessage(SAVE_FAILURE);
        }
    }
}
