package cn.fw.valhalla.controller.task;

import cn.fw.valhalla.common.utils.StringUtils;
import cn.fw.valhalla.domain.db.LeaveNeedDo;
import cn.fw.valhalla.service.bus.LeaveNeedDoBizService;
import com.alibaba.fastjson.JSONObject;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * @author : kurisu
 * @className : CallReportDealTask
 * @description : 通话记录处理任务
 * @date: 2021-01-19 16:02
 */
@Slf4j
@Component
@ConditionalOnProperty(prefix = "task", name = "switch", havingValue = "on")
public class RoleChangeTask {
    private final LeaveNeedDoBizService leaveNeedDoBizService;
    private final StringRedisTemplate redisTemplate;

    @Value("${spring.cache.custom.global-prefix}:mq:role:change")
    @Getter
    private String roleChangeKey;

    @Autowired
    public RoleChangeTask(final LeaveNeedDoBizService leaveNeedDoBizService,
                          final StringRedisTemplate redisTemplate) {
        this.leaveNeedDoBizService = leaveNeedDoBizService;
        this.redisTemplate = redisTemplate;
    }


    /**
     * 处理员工角色变动
     */
    @Scheduled(initialDelay = 1000 * 30, fixedRate = 1000 * 60 * 60)
    public void dealData() {
        List<String> failList = new ArrayList<>();
        String jsonStr;
        while ((jsonStr = redisTemplate.opsForList().leftPop(getRoleChangeKey())) != null) {
            LeaveNeedDo leaveNeedDo = JSONObject.parseObject(jsonStr, LeaveNeedDo.class);
            if (Objects.isNull(leaveNeedDo)) {
                continue;
            }
            try {
                leaveNeedDoBizService.add(leaveNeedDo);
            } catch (Exception e) {
                if (StringUtils.isValid(jsonStr)) {
                    failList.add(jsonStr);
                }
                log.error("处理员工角色变动失败", e);
            }
        }
        if (!CollectionUtils.isEmpty(failList)) {
            redisTemplate.opsForList().rightPushAll(getRoleChangeKey(), failList);
        }
    }
}
