package cn.fw.valhalla.component;

import cn.fw.erp.sdk.api.enums.OperateTypeEnum;
import cn.fw.erp.sdk.api.mq.RoleChangeEvent;
import cn.fw.valhalla.common.constant.RoleCode;
import cn.fw.valhalla.domain.db.LeaveNeedDo;
import cn.fw.valhalla.domain.enums.LeaveReasonEnum;
import cn.fw.valhalla.domain.enums.LeaveTodoTypeEnum;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import org.apache.rocketmq.spring.annotation.RocketMQMessageListener;
import org.apache.rocketmq.spring.core.RocketMQListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.Objects;

/**
 * @author : kurisu
 * @className : RoleChangeConsumer
 * @description : 角色变动mq
 * @date: 2021-01-28 09:49
 */
@Slf4j
@Component
@RocketMQMessageListener(topic = RoleChangeEvent.TOPIC, consumerGroup = "${spring.application.name}-" + RoleChangeEvent.TOPIC)
public class RoleChangeConsumer implements RocketMQListener<RoleChangeEvent> {
    private final StringRedisTemplate redisTemplate;

    @Value("${spring.cache.custom.global-prefix}:mq:role:change")
    @Getter
    private String roleChangeKey;

    @Autowired
    public RoleChangeConsumer(final StringRedisTemplate redisTemplate) {
        this.redisTemplate = redisTemplate;
    }

    @Override
    public void onMessage(RoleChangeEvent t) {
        log.info("监听角色变动mq: RoleChangeEvent=[{}]", t);
        try {
            if (Objects.isNull(t)) {
                return;
            }
            if (OperateTypeEnum.REMOVE.getValue().equals(t.getType()) && RoleCode.FWGW.equalsIgnoreCase(t.getRoleCode())) {
                Long shopId = t.getRangeValue();
                Long userId = t.getUserId();
                String userName = t.getUserName();
                LeaveNeedDo leaveNeedDo = createDb(userId, shopId, userName);
                redisTemplate.boundListOps(getRoleChangeKey()).rightPush(JSONObject.toJSONString(leaveNeedDo));
            }
        } catch (Exception ex) {
            log.error("消费角色变动mq失败，原因:{}", JSON.toJSONString(ex));
        }
    }

    private LeaveNeedDo createDb(Long userId, Long shopId, String userName) {
        LeaveNeedDo leaveNeedDo = new LeaveNeedDo();
        leaveNeedDo.setDone(Boolean.FALSE);
        leaveNeedDo.setEffectiveTime(new Date());
        leaveNeedDo.setReason(LeaveReasonEnum.CHANGE);
        leaveNeedDo.setType(LeaveTodoTypeEnum.CUSTOMER);
        leaveNeedDo.setShopId(shopId);
        leaveNeedDo.setUserId(userId);
        leaveNeedDo.setUserName(userName);
        leaveNeedDo.setCreateTime(new Date());
        return leaveNeedDo;
    }
}
